@@ -22,7 +22,6 @@ from .exceptions import (
     UnknownError,
 )
 from .models import CamelModel, FileDownloadRef
-from .responses import UJSONResponse
 from .utils import (
     async_get,
     force_async,
@@ -39,7 +38,7 @@ from .utils import (
 
 __author__ = "Samuel Bradley"
 __email__ = "sam.bradley@csiro.au"
-__version__ = "1.3.2"
+__version__ = "1.4.0"
 
 
 def create_app(
@@ -53,7 +52,6 @@ def create_app(
 
     if settings.ROLLBAR_KEY is not None:
         import rollbar
-        from rollbar.contrib.fastapi import add_to as rollbar_add_to
 
         rollbar.init(
             settings.ROLLBAR_KEY, environment=settings.ENVIRONMENT, handler="async", include_request_body=True
@@ -62,6 +60,8 @@ def create_app(
     app = FastAPI(title=settings.PROJECT_NAME, openapi_url=f"{settings.API_PRE_PATH}/openapi.json", **kwargs)
 
     if settings.ROLLBAR_KEY is not None:
+        from rollbar.contrib.fastapi import add_to as rollbar_add_to
+
         rollbar_add_to(app)
 
     # CORS
@@ -124,7 +124,7 @@ async def start_app(app: FastAPI):
         if not len(firebase_admin._apps):
             firebase_admin.initialize_app()
 
-    setup_db(app)
+    await setup_db(app)
     setup_storage(app)
     if get_settings().ENABLE_WORKFLOW:
         try:
@@ -136,6 +136,6 @@ async def start_app(app: FastAPI):
                 "Gitlab dependencies are missing, if you are planning to use workflows make sure the optional"
                 + " dependencies are installed"
             )
-            raise err  # App probably doesn't want to use gitlab
-
-    await create_indexes()
+            raise err from err
+    if not get_settings().USE_BEANIE:
+        await create_indexes()
