@@ -3,7 +3,6 @@ import os
 from enum import Enum
 from typing import List, Optional, Set
 
-from dotenv import load_dotenv
 from pydantic import BaseSettings, SecretBytes, SecretStr
 
 # from app.shared.utils import auth
@@ -28,7 +27,7 @@ class AuthType(str, Enum):
 
 
 class Settings(BaseSettings):
-    VERSION: str = "1.3.2"
+    VERSION: str = "1.4.0"
     API_VERSION: int = 1
     API_PRE_PATH: str = f"/api/v{API_VERSION}"
 
@@ -78,6 +77,7 @@ class Settings(BaseSettings):
 
     MONGODB_DSN: Optional[str] = None
     MONGODB_DBNAME: Optional[str] = None
+    USE_BEANIE: bool = False
     MONGO_AUTO_CONNECT: bool = True
     mongodb_min_pool_size: int = 0
     mongodb_max_pool_size: int = 100
@@ -87,6 +87,10 @@ class Settings(BaseSettings):
 
     debug_timing: bool = False
 
+    class Config:
+        env_file = ".env"
+        env_file_encoding = "utf-8"
+
     # class Config:
     #     env_prefix = 'FA_COMMON_'  # defaults to no prefix, i.e. ""
     #     fields = {
@@ -104,11 +108,9 @@ settings: Optional[Settings] = None
 
 def get_settings(env_path=None) -> Settings:
     # Load env variables from .env file
-    if env_path is not None:
-        load_dotenv(dotenv_path=env_path)
 
     global settings
     if settings is None or env_path is not None:
-        settings = Settings()
+        settings = Settings(_env_file=env_path)  # type: ignore
 
     return settings
