@@ -41,24 +41,23 @@ async def validation_exception_handler(request: Request, exc: RequestValidationE
     :param exc: StarletteHTTPException instance
     :return: UJSONResponse with newly formatted error data
     """
-    LOG.warning(f"RequestValidationError Caught: {str(exc)}")
+    LOG.warning(f"RequestValidationError Caught: {exc}")
     status_code = getattr(exc, "status_code", 422)
     errors = []
     details = str(exc)
     try:
-        for error in exc.errors():
-            errors.append(
-                {
-                    "area": error.get("loc", ("", ""))[0],
-                    "variable": error.get("loc", ("", ""))[1],
-                    "message": error.get("msg"),
-                    "type": error.get("type"),
-                }
-            )
+        errors.extend(
+            {
+                "area": error.get("loc", ("", ""))[0],
+                "variable": error.get("loc", ("", ""))[1],
+                "message": error.get("msg"),
+                "type": error.get("type"),
+            }
+            for error in exc.errors()
+        )
         details = "One or more fields has failed validation."
     except Exception as err:
         LOG.error(f"Problem creating validation error response. {err}")
-
     # FIXME make validation errors better
     data = {"code": "Validation Error", "detail": details, "errors": errors}
     return UJSONResponse(data, status_code=status_code)
@@ -106,7 +105,7 @@ async def assert_exception(request: Request, exc: AssertionError) -> UJSONRespon
 
 
 async def default_exception(request: Request, exc: Exception) -> UJSONResponse:
-    LOG.error(f"Internal exception caught: {str(exc)}")
+    LOG.error(f"Internal exception caught: {exc}")
     data = {
         "code": "Internal Server Error",
         "detail": str(exc),
