@@ -76,7 +76,10 @@ class UnknownError(HTTPException):
         :param detail: detailed message of the error
         """
         super().__init__(
-            error_name="Unknown Error", status_code=400, detail=detail, fields=fields,
+            error_name="Unknown Error",
+            status_code=400,
+            detail=detail,
+            fields=fields,
         )
 
 
@@ -98,7 +101,9 @@ class BadRequestError(HTTPException):
 
 class UnauthorizedError(HTTPException):
     def __init__(
-        self, detail: Any = "Unauthorized", fields: List[Dict] = None,
+        self,
+        detail: Any = "Unauthorized",
+        fields: List[Dict] = None,
     ):
         """
         Generic Unauthorized HTTP Exception with support for custom error code.
@@ -116,7 +121,9 @@ class UnauthorizedError(HTTPException):
 
 class ForbiddenError(HTTPException):
     def __init__(
-        self, detail: Any = "Forbidden.", fields: List[Dict] = None,
+        self,
+        detail: Any = "Forbidden.",
+        fields: List[Dict] = None,
     ):
         """
         Generic Forbidden HTTP Exception with support for custom error code.
@@ -125,13 +132,18 @@ class ForbiddenError(HTTPException):
         :param detail: detailed message of the error
         """
         super().__init__(
-            error_name="Forbidden Error", status_code=403, detail=detail, fields=fields,
+            error_name="Forbidden Error",
+            status_code=403,
+            detail=detail,
+            fields=fields,
         )
 
 
 class NotFoundError(HTTPException):
     def __init__(
-        self, detail: Any = "Not found.", fields: List[Dict] = None,
+        self,
+        detail: Any = "Not found.",
+        fields: List[Dict] = None,
     ):
         """
         Generic 404 Not Found HTTP Exception with support for custom error code.
@@ -140,13 +152,18 @@ class NotFoundError(HTTPException):
         :param detail: detailed message of the error
         """
         super().__init__(
-            error_name="Not Found Error", status_code=404, detail=detail, fields=fields,
+            error_name="Not Found Error",
+            status_code=404,
+            detail=detail,
+            fields=fields,
         )
 
 
 class AlreadyExistsError(HTTPException):
     def __init__(
-        self, detail: Any = "Already Exists.", fields: List[Dict] = None,
+        self,
+        detail: Any = "Already Exists.",
+        fields: List[Dict] = None,
     ):
         """
         409 Conflict HTTP Exception with support for custom error code.
