@@ -1,7 +1,9 @@
+from datetime import date, datetime, time
+
 from humps.camel import case
 from pydantic import BaseModel
+
 from .utils import get_timezone
-from datetime import datetime, date, time
 
 
 def to_camel(string):
@@ -13,13 +15,9 @@ class CamelModel(BaseModel):
         alias_generator = to_camel
         allow_population_by_field_name = True
         json_encoders = {
-            datetime: lambda dt: dt.replace(
-                microsecond=0, tzinfo=get_timezone()
-            ).isoformat(),
+            datetime: lambda dt: dt.replace(microsecond=0, tzinfo=get_timezone()).isoformat(),
             date: lambda date: date.isoformat(),
-            time: lambda time: time.replace(
-                microsecond=0, tzinfo=get_timezone()
-            ).isoformat(),
+            time: lambda time: time.replace(microsecond=0, tzinfo=get_timezone()).isoformat(),
         }
 
 
